# Health Management Software
Enter your weight for the last week and the average weight and weight trend will be calculated.<br>
Trends are calculated by linear interpolation or linear regression.<br>
Please install the library with the following command before starting the software.<br>
<!-- 直近一週間分の体重を入力すると、平均体重と体重の傾向を算出します。<br>
傾向は線形補間または線形回帰により算出されます。<br>
ソフトを起動する前に以下のコマンドでライブラリをインストールしてください。 -->
```python
pip install numpy
pip install scipy
pip install matplotlib.pyplot
pip install scikit-learn
```
[![Downloads](https://static.pepy.tech/badge/health-graph)](https://pepy.tech/project/health-graph)
[![Downloads](https://static.pepy.tech/badge/health-graph/month)](https://pepy.tech/project/health-graph)
[![Downloads](https://static.pepy.tech/badge/health-graph/week)](https://pepy.tech/project/health-graph)